/******************************************************************************/
/* AEL Sarl : Web hosting, datacenter, gestion et comptabilit dportes      */
/* Copyright (C) 2008 Affaires En Ligne S.A.R.L.                              */
/* Contact : contact@affaires-en-ligne.fr                                     */
/* Web : http://www.spidboutic.fr                                             */
/*                                                                            */
/* This program is free software; you can redistribute it and/or              */
/* modify it under the terms of the GNU General Public License                */
/* as published by the Free Software Foundation; either version 2             */
/* of the License, or (at your option) any later version.                     */
/*                                                                            */
/* This program is distributed in the hope that it will be useful,            */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of             */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the               */
/* GNU General Public License for more details.                               */
/*                                                                            */
/* You should have received a copy of the GNU General Public License          */
/* along with this program; if not, write to the Free Software                */
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/******************************************************************************/

/**
 * @classDescription Un observateur pour les onglets de l'assistant
 * @return {Object} retourne un nouvel objet AssistantObservateur
 * @constructor
 * @param {Object} id    identifiant de l'objet observateur
 */
function AssistantObservateur(id) {
    this.id = id;
    this.actif = true;
}

AssistantObservateur.prototype = {
    enregistrer: function() {},
    reset: function() {},
    init: function() {},
    estActif: function() { return this.actif; },
    activer: function() { this.actif = true; },
    desactiver: function() { this.actif = false; }
}

/**
 * @classDescription Un gestionnaire pour un pool d'observateurs
 * @return {Object} retourne un nouvel objet GestionnaireObservateurs
 * @constructor
 */
function GestionnaireObservateur() {
    this.observateurs = new Array();
}

GestionnaireObservateur.prototype = {
    
    /**
     * Ajouter un observateur  la liste
     * 
     * @method
     * @param {AssistantObservateur} obs    observateur  ajouter
     */
    ajouterObservateur: function(obs) {
        if (this.rechercherObservateur(obs) == -1) {
            this.observateurs.push(obs);
            setTimeout(function(){
                try {
                    obs.init();
                } catch (e) {}
            }, 600);
        }
    },

    /**
     * Rechercher un observateur enregistr
     * 
     * @method
     * @param {AssistantObservateur} obs    l'observateur dont on cherche l'existence
     * @return {int} l'index de l'observateur si il est trouv, -1 sinon
     */
    rechercherObservateur: function(obs) {
        for (var i = 0; i < this.observateurs.length; i++)
            if (this.observateurs[i].id == obs.id)
                return i;
        return -1;
    },

    /**
     * Rechercher un observateur enregistr par son id
     * 
     * @method
     * @param {String} id    l'identifiant de l'observateur dont on cherche l'existence
     * @return {AssistantObservateur} l'observateur si il est trouv, null sinon
     */
    rechercherObservateurParId: function (id) {
            for (var i = 0; i < this.observateurs.length; i++)
                if (this.observateurs[i].id == id)
                    return this.observateurs[i];
            return null;
    },
    
    /**
     * Drfrencer tous les observateurs enregistrs
     * 
     * @method
     */
    dereferencer: function() {
        this.observateurs.splice(0, this.observateurs.length);
    },
    
    resetTout: function() {
        for (var i = 0; i < this.observateurs.length; i++)
            this.observateurs[i].reset();
    },
    
    desactiverTout: function() {
        for (var i = 0; i < this.observateurs.length; i++)
            this.observateurs[i].desactiver();
    },
    
    enregistrerTout: function(data) {
        for (var i = 0; i < this.observateurs.length; i++)
            if (this.observateurs[i].estActif())
                this.observateurs[i].enregistrer(data);
    }
}
