/******************************************************************************/
/* AEL Sarl : Web hosting, datacenter, gestion et comptabilité déportées      */
/* Copyright (C) 2008 Affaires En Ligne S.A.R.L.                              */
/* Contact : contact@affaires-en-ligne.fr                                     */
/* Web : http://www.spidboutic.fr                                             */
/*                                                                            */
/* This program is free software; you can redistribute it and/or              */
/* modify it under the terms of the GNU General Public License                */
/* as published by the Free Software Foundation; either version 2             */
/* of the License, or (at your option) any later version.                     */
/*                                                                            */
/* This program is distributed in the hope that it will be useful,            */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of             */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the               */
/* GNU General Public License for more details.                               */
/*                                                                            */
/* You should have received a copy of the GNU General Public License          */
/* along with this program; if not, write to the Free Software                */
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/******************************************************************************/

package com.ael.util;

import java.io.File;
import java.io.IOException;
import java.awt.Color;
import java.awt.Transparency;
import java.awt.Graphics2D;
import java.awt.image.BufferedImage;
import javax.imageio.ImageIO;

/**
 * Classe permettant la copie d'une image, en la redimensionnant et sous un autre format
 * 
 * @author jm (AEL Sarl)
 *
 */
public class PhotoCopieur {

	private String src;

	/**
	 * Construit un <code>PhotoCopieur</code>
	 * 
	 * @param src_ fichier image d'origine
	 */
	public PhotoCopieur(String src_) {
		src = src_;
	}
	
	/**
	 * Construit un <code>PhotoCopieur</code>
	 */
	public PhotoCopieur() {
		src = null;
	}
	
	/**
	 * Fixe l'attribut src
	 * 
	 * @param src_	nouvelle valeur pour le fichier image
	 */
	public void setSrc(String src_) {
		src = src_;
	}

	/**
	 * Copier la photo dont le nom de fichier est enregistré dans l'objet
	 * 
	 * @param dst		fichier de destination
	 * @param largeur	largeur de la copie
	 * @param hauteur	hauteur de la copie
	 * @param format	format de la nouvelle image (JPG, PNG, GIF)
	 */
	public void copierPhoto(String dst, int largeur, int hauteur, String format) {
		if (src != null && !src.equals("")) {
			try {
				File fp = new File(src);
				if (fp.exists()) {
					BufferedImage bi = ImageIO.read(fp);
					if (bi != null) {
						int w = bi.getWidth();
						int h = bi.getHeight();
		
						if (w > largeur || h > hauteur) {
							if (w > h) {
								h = (h * largeur) / w;
								w = largeur;
							} else {
								w = (w * hauteur) / h;
								h = hauteur;
							}
						}
						BufferedImage bi2 = new BufferedImage (w, h, BufferedImage.TYPE_3BYTE_BGR);
						Graphics2D g2 = (Graphics2D) bi2.getGraphics();
						if (bi.getTransparency() != Transparency.OPAQUE) {
							g2.setColor(Color.WHITE);
							g2.fillRect(0, 0, w, h);
						}
						g2.drawImage(bi, 0, 0, w, h, null);
						File nouvelle = new File(dst);
						nouvelle.createNewFile();
						ImageIO.write(bi2, format, nouvelle);
					}
				}
			} catch (IOException ioe) {
				System.out.println("copierPhoto() : " + ioe);
				ioe.printStackTrace();
			}
		}
	}
	
	/**
	 * Supprimer le fichier source du copieur
	 */
	public void supprimerSource() {
		try {
			new File(src).delete();
			src = null;
		} catch(SecurityException se) {
			System.out.println("supprimerSource() : Impossible d'effacer le fichier image temporaire !");
			System.out.println(se);
		} 
	}
}
